﻿using System.Collections.Generic;

using DevExpress.XtraEditors;
using DevExpress.XtraPivotGrid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 팝업 폼
        /// </summary>
        private PopupForm popupForm;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.pivotGridControl.CellClick += pivotGridControl_CellClick;

            this.linqServerModeSource.QueryableSource = new DataClasses1DataContext().Invoices;

            SetPopupForm();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 피벗 그리드 컨트롤 셀 클릭시 처리하기 - pivotGridControl_CellClick(sender, e)

        /// <summary>
        /// 피벗 그리드 컨트롤 셀 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void pivotGridControl_CellClick(object sender, PivotCellEventArgs e)
        {
            PivotGridControl pivotGridControl = sender as PivotGridControl;

            if(this.popupForm.IsDisposed)
            {
                SetPopupForm();
            }

            if(!pivotGridControl.IsAsyncInProgress)
            {
                pivotGridControl.CreateDrillDownDataSourceAsync
                (
                    e.ColumnIndex,
                    e.RowIndex,
                    25,
                    new List<string> { "ProductName","Quantity" },
                    result => {
                        this.popupForm.DataSource = (PivotDrillDownDataSource)result.Value;
                    }
                );
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 팝업 폼 설정하기 - SetPopupForm()

        /// <summary>
        /// 팝업 폼 설정하기
        /// </summary>
        private void SetPopupForm()
        {
            this.popupForm = new PopupForm();

            this.popupForm.Show();
        }

        #endregion
    }
}